==> apache-ignite-2.5.0-src.zip: apache-ignite-2.5.0-src/modules/core/src/main/java/org/apache/ignite/internal/visor/tx/VisorTxSortOrder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.visor.tx;

import org.jetbrains.annotations.Nullable;

/**
 */
public enum VisorTxSortOrder {
    /** Sort by duration. */
    DURATION,
    /** Sort by size. */
    SIZE;

    /** Enumerated values. */
    private static final VisorTxSortOrder[] VALS = values();

    /**
     * Efficiently gets enumerated value from its ordinal.
     *
     * @param ord Ordinal value.
     * @return Enumerated value or {@code null} if ordinal out of range.
     */
    @Nullable public static VisorTxSortOrder fromOrdinal(int ord) {
        return ord >= 0 && ord < VALS.length ? VALS[ord] : null;
    }

    /**
     * @param name Name.
     */
    public static VisorTxSortOrder fromString(String name) {
        if (DURATION.toString().equals(name))
            return DURATION;

        if (SIZE.toString().equals(name))
            return SIZE;

        throw new IllegalArgumentException("Sort order is unknown: " + name);
    }
}

==> apache-ignite-2.7.0-src.zip: apache-ignite-2.7.0-src/modules/core/src/main/java/org/apache/ignite/internal/visor/tx/VisorTxSortOrder.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.ignite.internal.visor.tx;

import org.apache.ignite.internal.commandline.CommandHandler;
import org.jetbrains.annotations.Nullable;

/**
 */
public enum VisorTxSortOrder {
    /** Sort by duration. */
    DURATION,
    /** Sort by size. */
    SIZE,
    /** Sort by startTime */
    START_TIME;

    /** Enumerated values. */
    private static final VisorTxSortOrder[] VALS = values();

    /**
     * Efficiently gets enumerated value from its ordinal.
     *
     * @param ord Ordinal value.
     * @return Enumerated value or {@code null} if ordinal out of range.
     */
    @Nullable public static VisorTxSortOrder fromOrdinal(int ord) {
        return ord >= 0 && ord < VALS.length ? VALS[ord] : null;
    }

    /**
     * @param name Name.
     */
    public static VisorTxSortOrder fromString(String name) {
        if (DURATION.toString().equals(name))
            return DURATION;

        if (SIZE.toString().equals(name))
            return SIZE;

        if (CommandHandler.CMD_TX_ORDER_START_TIME.equals(name))
            return START_TIME;

        throw new IllegalArgumentException("Sort order is unknown: " + name);
    }
}
